"""Top-level package for <OPENDOTA/> API."""

from opendota.opendota import *

__author__ = """Hrishikesh Terdalkar"""
__email__ = 'hrishikeshrt@linuxmail.org'
__version__ = '0.2.4'

__all__ = ['OpenDota', 'FREQ_LOW', 'FREQ_MEDIUM', 'FREQ_HIGH']
